import { Injectable } from '@angular/core';
import { CookieService } from 'ngx-cookie-service';
import { Author } from './models/author';
import { BehaviorSubject } from 'rxjs';

@Injectable({
  providedIn: 'root'
})
export class AuthService {
  private sessionExpiredSubject = new BehaviorSubject<boolean>(false);
  sessionExpired$ = this.sessionExpiredSubject.asObservable();

  constructor(private cookieService: CookieService) {
    this.checkSessionExpiration();
  }

  isAuthenticated(): boolean {
    return this.cookieService.check("author") &&
      this.cookieService.check("token") &&
      this.cookieService.get("author") !== '' &&
      this.cookieService.get("token") !== '';
  }

  isSessionExpired(): boolean {
    return !(this.cookieService.check("author") &&
      this.cookieService.check("token")) &&
      !this.isAuthenticated();
  }

  getAuthenticatedAuthor(): Author {
    return JSON.parse(this.cookieService.get('author'));
  }

  getAuthenticatedAuthorToken(): string {
    return this.cookieService.get('token');
  }

  setSessionExpired(expired: boolean) {
    this.sessionExpiredSubject.next(expired);
  }

  checkSessionExpiration() {
    if (this.isSessionExpired()) {
      this.setSessionExpired(true);
    }
  }
}
